@@ -25,9 +25,9 @@ import requests
 try:
     from bs4 import BeautifulSoup
 except ImportError:
-        raise ImportError(
-            "BeautifulSoup4 não está instalado. Execute: pip install beautifulsoup4 lxml"
-        ) from None
+    raise ImportError(
+        "BeautifulSoup4 não está instalado. Execute: pip install beautifulsoup4 lxml"
+    ) from None
 
 try:
     from docling.datamodel.base_models import InputFormat
@@ -284,6 +284,9 @@ class DoclingWebScraper:
                     self.config.retry_delay * (2**attempt)
                 )  # Backoff exponencial
 
+        # Se chegou aqui, todas as tentativas falharam
+        raise NetworkError(f"Falha ao baixar conteúdo após {self.config.retry_attempts} tentativas")
+
     def _convert_to_markdown(self, html_content: str, source_url: str) -> tuple:
         """Converte HTML para markdown."""
         if self.docling_converter:
@@ -343,7 +346,7 @@ class DoclingWebScraper:
             markdown_lines = []
 
             # Processar elementos
-            for element in main_content.find_all(
+            for element in main_content.find_all(  # type: ignore
                 [
                     "h1",
                     "h2",
@@ -412,18 +415,18 @@ class DoclingWebScraper:
                 soup.find("title"),
                 soup.find("h1"),
                 soup.find("meta", property="og:title"),
-                soup.find("meta", name="twitter:title"),
+                soup.find("meta", attrs={"name": "twitter:title"}),
             ]
 
             for source in title_sources:
                 if source:
-                    if source.name == "meta":
-                        title = source.get("content", "").strip()
+                    if hasattr(source, 'name') and source.name == "meta":  # type: ignore
+                        title = source.get("content", "").strip()  # type: ignore
                     else:
-                        title = source.get_text().strip()
+                        title = source.get_text().strip()  # type: ignore
 
                     if title:
-                        return title
+                        return title  # type: ignore
 
             return "Conteúdo Extraído"
 
@@ -455,15 +458,15 @@ class DoclingWebScraper:
                 for meta_name in meta_names:
                     meta_tag = soup.find(
                         "meta", attrs={"name": meta_name}
-                    ) or soup.find("meta", attrs={"property": meta_name})
-                    if meta_tag and meta_tag.get("content"):
-                        metadata[key] = meta_tag["content"].strip()
+                    ) or soup.find("meta", attrs={"property": meta_name})  # type: ignore
+                    if meta_tag and meta_tag.get("content"):  # type: ignore
+                        metadata[key] = meta_tag["content"].strip()  # type: ignore
                         break
 
             # Estatísticas do conteúdo
             text_content = soup.get_text()
-            metadata["word_count"] = len(text_content.split())
-            metadata["char_count"] = len(text_content)
+            metadata["word_count"] = str(len(text_content.split()))
+            metadata["char_count"] = str(len(text_content))
 
             return metadata
 
